@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 """
 :copyright:
-    Lion Krischer (krischer@geophysik.uni-muenchen.de), 2013-2014
+    Lion Krischer (krischer@geophysik.uni-muenchen.de), 2013-2018
 :license:
     BSD 3-Clause ("BSD New" or "BSD Simplified")
 """
@@ -265,7 +265,7 @@ class AuxiliaryDataContainer(object):
             # It might be returned as a byte string on some systems.
             try:
                 self.provenance_id = self.provenance_id.decode()
-            except:  # pragma: no cover
+            except Exception:  # pragma: no cover
                 pass
         else:
             self.provenance_id = None
@@ -295,7 +295,7 @@ class AuxiliaryDataContainer(object):
     def __del__(self):
         try:
             self.__file_cache.close()
-        except:
+        except Exception:
             pass
 
     @property
@@ -726,6 +726,39 @@ class WaveformAccessor(object):
     def __ne__(self, other):
         return not self.__eq__(other)
 
+    def get_waveform_attributes(self):
+        """
+        Get a dictionary of the attributes of all waveform data sets.
+
+        This works purely on the meta data level and is thus fast. Event,
+        origin, arrival, and focmec ids will be returned as lists as they can
+        be set multiple times per data-set.
+        """
+        plural_keys = ["event_id", "origin_id",
+                       "magnitude_id", "focal_mechanism_id"]
+
+        attributes = {}
+        for _i in self.list():
+            if _i == "StationXML":
+                continue
+
+            attrs = {}
+            for k, v in self.__hdf5_group[_i].attrs.items():
+                # Make sure its an actual string.
+                try:
+                    v = v.decode()
+                except Exception:
+                    pass
+
+                if k in plural_keys:
+                    k += "s"
+                    v = v.split(",")
+                attrs[k] = v
+            if attrs:
+                attributes[_i] = attrs
+
+        return attributes
+
     @property
     def coordinates(self):
         """
@@ -1293,7 +1326,7 @@ def to_list_of_resource_identifiers(obj, name, obj_type):
     else:
         try:
             obj = obspy.core.event.ResourceIdentifier(obj)
-        except:
+        except Exception:
             msg = "Invalid type for %s." % name
             raise TypeError(msg)
     return [obj]
